@@ -42,7 +42,7 @@ big_int_octal: {
 }
 
 big_int_no_e: {
-    input: `1e3n`
+    bad_input: `1e3n`
     expect_error: ({
         name: "SyntaxError",
         message: "Invalid or unexpected token"
@@ -50,7 +50,7 @@ big_int_no_e: {
 }
 
 big_int_bad_digits_for_base: {
-    input: `0o9n`
+    bad_input: `0o9n`
     expect_error: ({
         name: "SyntaxError",
         message: "Invalid or unexpected token"
@@ -62,12 +62,30 @@ big_int_math: {
         defaults: true
     }
     input: {
-        const sum = 10n + 15n;
-        const exp = 5n ** 10n;
-        const sub = 1n - 3n;
-        const mul = 5n * 5n;
-        const div = 15n / 5n;
-        const regular_number = 1 * 10;
+        console.log({
+            sum: 10n + 15n,
+            exp: 2n ** 3n,
+            sub: 1n - 3n,
+            mul: 5n * 5n,
+            div: 15n / 5n,
+        });
     }
-    expect_exact: "const sum=10n+15n,exp=5n**10n,sub=1n-3n,mul=5n*5n,div=15n/5n,regular_number=10;"
+    expect_exact: "console.log({sum:25n,exp:8n,sub:-2n,mul:25n,div:3n});"
+    expect_stdout: true
+}
+
+big_int_math_counter_examples: {
+    node_version = ">= 12"
+    options = {
+        defaults: true
+    }
+    input: {
+        console.log({
+            mixing_types: 1 * 10n,
+            bad_shift: 1n >>> 0n,
+            bad_div: 1n / 0n,
+        });
+    }
+    expect_exact: "console.log({mixing_types:1*10n,bad_shift:1n>>>0n,bad_div:1n/0n});"
+    expect_stdout: true
 }
